@@ -53,3 +53,7 @@ class BaseError(Model):
     path: str
     status: int
     detail: str
+
+
+class ExtendedBaseError(BaseError):
+    error_key: str
