@@ -1,15 +1,16 @@
 import asyncio
 import warnings
+from collections.abc import Callable
 from functools import wraps
-from typing import Callable, TypeVar
+from typing import ParamSpec, TypeVar
 
 import pydantic
-from pydantic import BaseModel
-from typing_extensions import ParamSpec
+
+from souswift_core.models import Model
 
 T = TypeVar('T')
 P = ParamSpec('P')
-ModelT = TypeVar('ModelT', bound=BaseModel)
+ModelT = TypeVar('ModelT', bound=Model)
 
 
 def deprecated(func: Callable[P, T]) -> Callable[P, T]:
